@@ -88,7 +88,7 @@ class FileServerConnector:
         return dict_to_dataclass(answer, FileLink)
 
     async def add_file(self, file: bytes, filename: str, is_thumbnail_required: bool = False) -> FileLink:
-        args = {"filename": filename, "is_thumbnail_required": str(is_thumbnail_required)}
+        args = {"filename": filename, "is_thumbnail_required": str(is_thumbnail_required).lower()}
         answer = await self._connector.post("/file/add", payload=file, url_query=args,
                                             headers=self._construct_headers())
         original = answer.get("original")
